# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# We need to patch the test suite if we have an old version of Test::More
%global old_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.88) ? 1 : 0);' 2>/dev/null || echo 0)
%global older_test_more %(perl -MTest::More -e 'print (($Test::More::VERSION < 0.82) ? 1 : 0);' 2>/dev/null || echo 0)

Name:		perl-Data-OptList
Version:	0.110
Release:	2.%{__distinit}%{__distvers}
Summary:	Parse and validate simple name/value option pairs
License:	GPL+ or Artistic
Group:		Development/Libraries
URL:		http://search.cpan.org/dist/Data-OptList/
Source0:	http://search.cpan.org/CPAN/authors/id/R/RJ/RJBS/Data-OptList-%{version}.tar.gz
Patch1:		Data-OptList-0.110-old-Test::More.patch
Patch2:		Data-OptList-0.110-note.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl
%if 0%{?fedora} > 20 || 0%{?rhel} > 7
BuildRequires:	perl-generators
%endif
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(List::Util)
BuildRequires:	perl(Params::Util)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Install) >= 0.921
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::More) >= 0.47
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
# Extra Tests
BuildRequires:	perl(Test::Pod) >= 1.41
# Dependencies
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))

%description
Hashes are great for storing named data, but if you want more than one entry
for a name, you have to use a list of pairs. Even then, this is really boring
to write:

$values = [
    foo => undef,
    bar => undef,
    baz => undef,
    xyz => { ... },
];

With Data::OptList, you can do this instead:

$values = Data::OptList::mkopt([
    qw(foo bar baz),
    xyz => { ... },
]);

This works by assuming that any defined scalar is a name and any reference
following a name is its value.

%prep
%setup -q -n Data-OptList-%{version}

# We don't really need Test::More ≥ 0.88
%if %{old_test_more}
%patch1
%endif

# We don't really need Test::More ≥ 0.82 either
%if %{older_test_more}
%patch2
%endif

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} %{buildroot}

%check
make test
make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"

%clean
rm -rf %{buildroot}

%files
%if 0%{?_licensedir:1}
%license LICENSE
%else
%doc LICENSE
%endif
%doc Changes README
%{perl_vendorlib}/Data/
%{_mandir}/man3/Data::OptList.3*

%changelog
* Mon Aug 15 2016 Paul Howarth <paul@city-fan.org> - 0.110-2
- BR: perl-generators where available

* Fri Mar 25 2016 Paul Howarth <paul@city-fan.org> - 0.110-1
- Update to 0.110
  - Major optimization to mkopt
- Classify buildreqs by usage
- Simplify find expression using -delete
- Update patches as needed

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 0.109-3
- Drop support for old distributions prior to FC-5:
  - Drop %%defattr, redundant since rpm 4.4
  - Drop support for building with ExtUtils::MakeMaker < 6.30
- Use %%license where possible

* Fri Dec 13 2013 Paul Howarth <paul@city-fan.org> - 0.109-1
- Update to 0.109
  - Update bugtracker and repo links
- Update patches as needed

* Thu Jul 18 2013 Paul Howarth <paul@city-fan.org> - 0.108-2
- Perl 5.18 rebuild

* Sat Jul  6 2013 Paul Howarth <paul@city-fan.org> - 0.108-1
- Update to 0.108
  - Repackage, new bug tracker
- Explicitly run the extra tests
- Update patches
- Add new patch to support build with Test::More < 0.82 (note)

* Tue Jul  3 2012 Paul Howarth <paul@city-fan.org> - 0.107-6
- Don't need to remove empty directories from the buildroot
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}
  - Use DESTDIR rather than PERL_INSTALL_ROOT

* Fri Jan 20 2012 Paul Howarth <paul@city-fan.org> - 0.107-3
- Drop redundant buildreq perl(Test::Pod::Coverage)
- BR: perl(ExtUtils::MakeMaker), perl(List::Util) and perl(Test::More)

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 0.107-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Fri May  6 2011 Paul Howarth <paul@city-fan.org> - 0.107-1
- Update to 0.107
  - mkopt now prefers named parameters; docs updated
  - Added the name_test parameter to mkopt
- Nobody else likes macros for commands

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.106-3
- Rebuild for perl 5.12.1 in Rawhide

* Tue Jun  8 2010 Paul Howarth <paul@city-fan.org> - 0.106-2
- Fix dist tag for RHEL-6 Beta

* Mon Feb 15 2010 Paul Howarth <paul@city-fan.org> - 0.106-1
- Update to 0.106 (correct version style mismatch for Sub::Install)
- Bump dependency on Sub::Install to 0.921
- Use %%{_fixperms} macro instead of our own %%{__chmod} incantation

* Fri Jan 15 2010 Paul Howarth <paul@city-fan.org> - 0.105-1
- Update to 0.105 (fix a typo in documentation)

* Wed Sep  9 2009 Paul Howarth <paul@city-fan.org> - 0.104-2
- Define RPM macros in global scope

* Thu Jan 22 2009 Paul Howarth <paul@city-fan.org> - 0.104-1
- Update to 0.104

* Mon Sep  1 2008 Paul Howarth <paul@city-fan.org> - 0.103-3
- Import from Fedora

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.103-2
- Rebuild for perl 5.10 (again)

* Thu Jan 24 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.103-1
- Rebuild for new perl
- Bump to 0.103
- Fix license tag

* Thu Sep 07 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.101-2
- Bump

* Sat Sep 02 2006 Chris Weyl <cweyl@alumni.drew.edu> - 0.101-1
- Specfile autogenerated by cpanspec 1.69.1
